@@ -340,34 +340,35 @@ set_item_message (WindowData   *data,
 	GeditFileBrowserStore *store;
 	GFile *location;
 	guint flags = 0;
-	gchar *track_id;
 
 	store = gedit_file_browser_widget_get_browser_store (data->widget);
-
 	gtk_tree_model_get (GTK_TREE_MODEL (store), iter,
 			    GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION, &location,
 			    GEDIT_FILE_BROWSER_STORE_COLUMN_FLAGS, &flags,
 			    -1);
 
-	if (!location)
-		return;
+	if (location)
+	{
+		gchar *track_id;
 
-	if (path && gtk_tree_path_get_depth (path) != 0)
-		track_id = track_row (data, store, path, location);
-	else
-		track_id = NULL;
+		if (path && gtk_tree_path_get_depth (path) != 0)
+			track_id = track_row (data, store, path, location);
+		else
+			track_id = NULL;
 
-	gedit_message_set (message,
-			   "id", track_id,
-			   "location", location,
-			   NULL);
-
-	if (gedit_message_has_key (message, "is_directory"))
 		gedit_message_set (message,
-				   "is_directory", FILE_IS_DIR (flags),
+				   "id", track_id,
+				   "location", location,
 				   NULL);
 
-	g_free (track_id);
+		if (gedit_message_has_key (message, "is_directory"))
+			gedit_message_set (message,
+					   "is_directory", FILE_IS_DIR (flags),
+					   NULL);
+
+		g_free (track_id);
+		g_object_unref (location);
+	}
 }
 
 static gboolean
@@ -399,6 +400,8 @@ custom_message_filter_func (GeditFileBrowserWidget *widget,
 	gedit_message_bus_send_message_sync (wdata->bus, data->message);
 	gedit_message_get (data->message, "filter", &filter, NULL);
 
+	g_object_unref (location);
+
 	return !filter;
 }
 
